@@ -58,7 +58,7 @@ class Redis
 
   class MultiConnection < PipelinedConnection
     def multi
-      raise Redis::Error, "Can't nest multi transaction"
+      raise Redis::BaseError, "Can't nest multi transaction"
     end
 
     private
@@ -118,12 +118,14 @@ class Redis
     end
 
     def _set(replies)
-      if replies
-        @futures.each_with_index do |future, index|
+      @object = if replies
+        @futures.map.with_index do |future, index|
           future._set(replies[index])
+          future.value
         end
+      else
+        replies
       end
-      @object = replies
     end
   end
 end
