@@ -3,7 +3,6 @@
 module Lint
   module Streams
     MIN_REDIS_VERSION = '4.9.0'
-    MIN_REDIS_VERSION_XAUTOCLAIM = '6.2.0'
     ENTRY_ID_FORMAT = /\d+-\d+/.freeze
 
     def setup
@@ -90,8 +89,18 @@ module Lint
       assert_match ENTRY_ID_FORMAT, actual
     end
 
+    def test_xadd_with_nomkstream_option
+      omit_version('6.2.0')
+
+      actual = redis.xadd('s1', { f1: 'v1', f2: 'v2' }, nomkstream: true)
+      assert_nil actual
+
+      actual = redis.xadd('s1', { f1: 'v1', f2: 'v2' }, nomkstream: false)
+      assert_match ENTRY_ID_FORMAT, actual
+    end
+
     def test_xadd_with_invalid_arguments
-      assert_raises(Redis::CommandError) { redis.xadd(nil, {}) }
+      assert_raises(TypeError) { redis.xadd(nil, {}) }
       assert_raises(Redis::CommandError) { redis.xadd('', {}) }
       assert_raises(Redis::CommandError) { redis.xadd('s1', {}) }
     end
@@ -112,6 +121,62 @@ module Lint
       assert_equal 0, redis.xtrim('s1', 2, approximate: true)
     end
 
+    def test_xtrim_with_limit_option
+      omit_version('6.2.0')
+
+      begin
+        original = redis.config(:get, 'stream-node-max-entries')['stream-node-max-entries']
+        redis.config(:set, 'stream-node-max-entries', 1)
+
+        redis.xadd('s1', { f: 'v1' })
+        redis.xadd('s1', { f: 'v2' })
+        redis.xadd('s1', { f: 'v3' })
+        redis.xadd('s1', { f: 'v4' })
+
+        assert_equal 1, redis.xtrim('s1', 0, approximate: true, limit: 1)
+        error = assert_raises(Redis::CommandError) { redis.xtrim('s1', 0, limit: 1) }
+        assert_includes error.message, "ERR syntax error, LIMIT cannot be used without the special ~ option"
+      ensure
+        redis.config(:set, 'stream-node-max-entries', original)
+      end
+    end
+
+    def test_xtrim_with_maxlen_strategy
+      redis.xadd('s1', { f: 'v1' }, id: '0-1')
+      redis.xadd('s1', { f: 'v1' }, id: '0-2')
+      redis.xadd('s1', { f: 'v1' }, id: '1-0')
+      redis.xadd('s1', { f: 'v1' }, id: '1-1')
+      assert_equal(2, redis.xtrim('s1', 2, strategy: 'MAXLEN'))
+    end
+
+    def test_xtrim_with_minid_strategy
+      omit_version('6.2.0')
+
+      redis.xadd('s1', { f: 'v1' }, id: '0-1')
+      redis.xadd('s1', { f: 'v1' }, id: '0-2')
+      redis.xadd('s1', { f: 'v1' }, id: '1-0')
+      redis.xadd('s1', { f: 'v1' }, id: '1-1')
+      assert_equal(2, redis.xtrim('s1', '1-0', strategy: 'MINID'))
+    end
+
+    def test_xtrim_with_approximate_minid_strategy
+      omit_version('6.2.0')
+
+      redis.xadd('s1', { f: 'v1' }, id: '0-1')
+      redis.xadd('s1', { f: 'v1' }, id: '0-2')
+      redis.xadd('s1', { f: 'v1' }, id: '1-0')
+      redis.xadd('s1', { f: 'v1' }, id: '1-1')
+      assert_equal(0, redis.xtrim('s1', '1-0', strategy: 'MINID', approximate: true))
+    end
+
+    def test_xtrim_with_invalid_strategy
+      omit_version('6.2.0')
+
+      redis.xadd('s1', { f: 'v1' })
+      error = assert_raises(Redis::CommandError) { redis.xtrim('s1', '1-0', strategy: '') }
+      assert_includes error.message, "ERR syntax error"
+    end
+
     def test_xtrim_with_not_existed_stream
       assert_equal 0, redis.xtrim('not-existed-stream', 2)
     end
@@ -119,12 +184,10 @@ module Lint
     def test_xtrim_with_invalid_arguments
       if version >= '6.2'
         assert_raises(Redis::CommandError) { redis.xtrim('', '') }
-        assert_raises(Redis::CommandError) { redis.xtrim(nil, nil) }
         assert_equal 0, redis.xtrim('s1', 0)
         assert_raises(Redis::CommandError) { redis.xtrim('s1', -1, approximate: true) }
       else
         assert_equal 0, redis.xtrim('', '')
-        assert_equal 0, redis.xtrim(nil, nil)
         assert_equal 0, redis.xtrim('s1', 0)
         assert_equal 0, redis.xtrim('s1', -1, approximate: true)
       end
@@ -146,8 +209,8 @@ module Lint
     end
 
     def test_xdel_with_invalid_arguments
-      assert_equal 0, redis.xdel(nil, nil)
-      assert_equal 0, redis.xdel(nil, [nil])
+      assert_raises(TypeError) { redis.xdel(nil, nil) }
+      assert_raises(TypeError) { redis.xdel(nil, [nil]) }
       assert_equal 0, redis.xdel('', '')
       assert_equal 0, redis.xdel('', [''])
       assert_raises(Redis::CommandError) { redis.xdel('s1', []) }
@@ -222,7 +285,7 @@ module Lint
     end
 
     def test_xrange_with_invalid_arguments
-      assert_equal([], redis.xrange(nil))
+      assert_raises(TypeError) { redis.xrange(nil) }
       assert_equal([], redis.xrange(''))
     end
 
@@ -298,7 +361,7 @@ module Lint
     end
 
     def test_xrevrange_with_invalid_arguments
-      assert_equal([], redis.xrevrange(nil))
+      assert_raises(TypeError) { redis.xrevrange(nil) }
       assert_equal([], redis.xrevrange(''))
     end
 
@@ -313,7 +376,7 @@ module Lint
     end
 
     def test_xlen_with_invalid_key
-      assert_equal 0, redis.xlen(nil)
+      assert_raises(TypeError) { redis.xlen(nil) }
       assert_equal 0, redis.xlen('')
     end
 
@@ -357,19 +420,20 @@ module Lint
     def test_xread_does_not_raise_timeout_error_when_the_block_option_is_zero_msec
       prepared = false
       actual = nil
-      wire = Wire.new do
+      thread = Thread.new do
         prepared = true
         actual = redis.xread('s1', 0, block: 0)
       end
-      Wire.pass until prepared
-      redis.dup.xadd('s1', { f: 'v1' }, id: '0-1')
-      wire.join
+      Thread.pass until prepared
+      redis2 = init _new_client
+      redis2.xadd('s1', { f: 'v1' }, id: '0-1')
+      thread.join(3)
 
       assert_equal(['v1'], actual.fetch('s1').map { |i| i.last['f'] })
     end
 
     def test_xread_with_invalid_arguments
-      assert_raises(Redis::CommandError) { redis.xread(nil, nil) }
+      assert_raises(TypeError) { redis.xread(nil, nil) }
       assert_raises(Redis::CommandError) { redis.xread('', '') }
       assert_raises(Redis::CommandError) { redis.xread([], []) }
       assert_raises(Redis::CommandError) { redis.xread([''], ['']) }
@@ -481,7 +545,7 @@ module Lint
     end
 
     def test_xreadgroup_with_invalid_arguments
-      assert_raises(Redis::CommandError) { redis.xreadgroup(nil, nil, nil, nil) }
+      assert_raises(TypeError) { redis.xreadgroup(nil, nil, nil, nil) }
       assert_raises(Redis::CommandError) { redis.xreadgroup('', '', '', '') }
       assert_raises(Redis::CommandError) { redis.xreadgroup('', '', [], []) }
       assert_raises(Redis::CommandError) { redis.xreadgroup('', '', [''], ['']) }
@@ -534,7 +598,7 @@ module Lint
     end
 
     def test_xack_with_invalid_arguments
-      assert_equal 0, redis.xack(nil, nil, nil)
+      assert_raises(TypeError) { redis.xack(nil, nil, nil) }
       assert_equal 0, redis.xack('', '', '')
       assert_raises(Redis::CommandError) { redis.xack('', '', []) }
       assert_equal 0, redis.xack('', '', [''])
@@ -641,12 +705,12 @@ module Lint
     end
 
     def test_xclaim_with_invalid_arguments
-      assert_raises(Redis::CommandError) { redis.xclaim(nil, nil, nil, nil, nil) }
+      assert_raises(TypeError) { redis.xclaim(nil, nil, nil, nil, nil) }
       assert_raises(Redis::CommandError) { redis.xclaim('', '', '', '', '') }
     end
 
     def test_xautoclaim
-      omit_version(MIN_REDIS_VERSION_XAUTOCLAIM)
+      omit_version('6.2.0')
 
       redis.xadd('s1', { f: 'v1' }, id: '0-1')
       redis.xgroup(:create, 's1', 'g1', '$')
@@ -663,7 +727,7 @@ module Lint
     end
 
     def test_xautoclaim_with_justid_option
-      omit_version(MIN_REDIS_VERSION_XAUTOCLAIM)
+      omit_version('6.2.0')
 
       redis.xadd('s1', { f: 'v1' }, id: '0-1')
       redis.xgroup(:create, 's1', 'g1', '$')
@@ -679,7 +743,7 @@ module Lint
     end
 
     def test_xautoclaim_with_count_option
-      omit_version(MIN_REDIS_VERSION_XAUTOCLAIM)
+      omit_version('6.2.0')
 
       redis.xadd('s1', { f: 'v1' }, id: '0-1')
       redis.xgroup(:create, 's1', 'g1', '$')
@@ -696,7 +760,7 @@ module Lint
     end
 
     def test_xautoclaim_with_larger_interval
-      omit_version(MIN_REDIS_VERSION_XAUTOCLAIM)
+      omit_version('6.2.0')
 
       redis.xadd('s1', { f: 'v1' }, id: '0-1')
       redis.xgroup(:create, 's1', 'g1', '$')
@@ -711,6 +775,22 @@ module Lint
       assert_equal [], actual['entries']
     end
 
+    def test_xautoclaim_with_deleted_entry
+      omit_version('6.2.0')
+
+      redis.xadd('s1', { f: 'v1' }, id: '0-1')
+      redis.xgroup(:create, 's1', 'g1', '$')
+      redis.xadd('s1', { f: 'v2' }, id: '0-2')
+      redis.xreadgroup('g1', 'c1', 's1', '>')
+      redis.xdel('s1', '0-2')
+      sleep 0.01
+
+      actual = redis.xautoclaim('s1', 'g1', 'c2', 0, '0-0')
+
+      assert_equal '0-0', actual['next']
+      assert_equal [], actual['entries']
+    end
+
     def test_xpending
       redis.xadd('s1', { f: 'v1' }, id: '0-1')
       redis.xgroup(:create, 's1', 'g1', '$')
@@ -752,6 +832,51 @@ module Lint
       assert_equal 1, actual[2]['count']
     end
 
+    def test_xpending_with_range_and_idle_options
+      target_version "6.2" do
+        redis.xadd('s1', { f: 'v1' }, id: '0-1')
+        redis.xgroup(:create, 's1', 'g1', '$')
+        redis.xadd('s1', { f: 'v2' }, id: '0-2')
+        redis.xadd('s1', { f: 'v3' }, id: '0-3')
+        redis.xreadgroup('g1', 'c1', 's1', '>')
+
+        actual = redis.xpending('s1', 'g1', '-', '+', 10)
+        assert_equal 2, actual.size
+        actual = redis.xpending('s1', 'g1', '-', '+', 10, idle: 10)
+        assert_equal 0, actual.size
+        sleep 0.1
+        actual = redis.xpending('s1', 'g1', '-', '+', 10, idle: 10)
+        assert_equal 2, actual.size
+
+        redis.xadd('s1', { f: 'v4' }, id: '0-4')
+        redis.xreadgroup('g1', 'c2', 's1', '>')
+
+        actual = redis.xpending('s1', 'g1', '-', '+', 10, idle: 1000)
+        assert_equal 0, actual.size
+
+        actual = redis.xpending('s1', 'g1', '-', '+', 10)
+        assert_equal 3, actual.size
+        actual = redis.xpending('s1', 'g1', '-', '+', 10, idle: 10)
+        assert_equal 2, actual.size
+        sleep 0.01
+        actual = redis.xpending('s1', 'g1', '-', '+', 10, idle: 10)
+        assert_equal 3, actual.size
+
+        assert_equal '0-2', actual[0]['entry_id']
+        assert_equal 'c1', actual[0]['consumer']
+        assert_equal true, actual[0]['elapsed'] >= 0
+        assert_equal 1, actual[0]['count']
+        assert_equal '0-3', actual[1]['entry_id']
+        assert_equal 'c1', actual[1]['consumer']
+        assert_equal true, actual[1]['elapsed'] >= 0
+        assert_equal 1, actual[1]['count']
+        assert_equal '0-4', actual[2]['entry_id']
+        assert_equal 'c2', actual[2]['consumer']
+        assert_equal true, actual[2]['elapsed'] >= 0
+        assert_equal 1, actual[2]['count']
+      end
+    end
+
     def test_xpending_with_range_and_consumer_options
       redis.xadd('s1', { f: 'v1' }, id: '0-1')
       redis.xgroup(:create, 's1', 'g1', '$')
